pub struct Point {
pub x: f64,
pub y: f64,
}Expand description
A meaningful spacial coordinate.
Most transformations of this type return a Vector, that is not
bound to mean a location in space. Vectors can be converted back
into points if the programmer determines they again represent a
coordinate in space with Vector::p()
Fields
x: f64y: f64Implementations
Sourceimpl Point
impl Point
Sourcepub fn new(x: f64, y: f64) -> Self
pub fn new(x: f64, y: f64) -> Self
Create new point. This is just a helper given the fields are public.
Sourcepub fn close_to(&self, other: &Point, epsilon: f64) -> bool
pub fn close_to(&self, other: &Point, epsilon: f64) -> bool
Returns true of this point is within epsilon distance of other
uses euclidian squared distance internally for speed.
Sourcepub fn distance(&self, other: &Point) -> f64
pub fn distance(&self, other: &Point) -> f64
calulates the euclidian distance between this point and other
Sourcepub fn distance_2(&self, other: &Point) -> f64
pub fn distance_2(&self, other: &Point) -> f64
calulates the euclidian squared distance between this point and other
mostly useful as an optimisation to save the square root when comparing distnaces