pub struct Vector {
pub x: f64,
pub y: f64,
}Expand description
A standard 2D vector implementaion.
Fields
x: f64y: f64Implementations
Sourceimpl Vector
impl Vector
Sourcepub fn new(x: f64, y: f64) -> Self
pub fn new(x: f64, y: f64) -> Self
Create new vector. This is just a helper given the fields are public.
Sourcepub fn normalized(&self) -> Vector
pub fn normalized(&self) -> Vector
returns a copy of this vector with a length of 1
Sourcepub fn scale_e(&self, sx: f64, sy: f64) -> Vector
pub fn scale_e(&self, sx: f64, sy: f64) -> Vector
element wise scaling with seperate x and y scaling factors
Sourcepub fn rotate(&self, theta: f64) -> Vector
pub fn rotate(&self, theta: f64) -> Vector
apply a rotation matrix constructed around theta to this vector
Sourcepub fn reflect(&self, normal: &Vector) -> Vector
pub fn reflect(&self, normal: &Vector) -> Vector
Caluate a normal reflection of this vector as a direction vector
against a surface with a normal vector of normal.
Parameters:
- self: a
Vectorrepresenting the direction to be relected. - normal: a
Vectorrepresenting the normal of the surface being reflected off.
Neither vector needs to be normalised.